@@ -370,6 +370,18 @@
 #  undef MONGOC_ENABLE_ICU
 #endif
 
+
+/*
+ * Set if we have Client Side Encryption support.
+ */
+
+#define MONGOC_ENABLE_CLIENT_SIDE_ENCRYPTION 0
+
+#if MONGOC_ENABLE_CLIENT_SIDE_ENCRYPTION != 1
+#  undef MONGOC_ENABLE_CLIENT_SIDE_ENCRYPTION
+#endif
+
+
 /*
  * Set if struct sockaddr_storage has __ss_family (instead of ss_family)
  */
@@ -385,7 +397,7 @@
  * If you're about to update this file and add a config flag, make sure to
  * update:
  * o The bitfield in mongoc-handshake-private.h
- * o _get_config_bitfield() in mongoc-handshake.c
+ * o _mongoc_handshake_get_config_hex_string() in mongoc-handshake.c
  * o examples/parse_handshake_cfg.py
  * o test_handshake_config_string in test-mongoc-handshake.c
  */
